@@ -11,8 +11,8 @@ class Request:
     proxies = None
     allow_webp = True
     user_agent = '{} {}'.format(
-        'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:76.0)',
-        'Gecko/20100101 Firefox/76.0'
+        'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:91.0)',
+        'Gecko/20100101 Firefox/91.0'
     )
     default_lang = 'ru-RU,ru;q=0.8,en-US;q=0.5,en;q=0.3'
     cookies = None
@@ -20,6 +20,7 @@ class Request:
     response = None
     _history = None
     allow_send_referer = True
+    webp_header = 'text/html,application/xhtml+xml,application/xml;q=1.0,image/webp,image/apng,*/*;q=1.0'
 
     def __init__(self):
         self.proxies = {}
@@ -92,7 +93,7 @@ class Request:
             headers.setdefault('Referer', self.referer)
         headers.setdefault('Accept-Language', self.default_lang)
         if self.allow_webp:
-            headers['Accept'] = 'text/html,application/xhtml+xml,application/xml;q=1.0,image/webp,image/apng,*/*;q=1.0'
+            headers['Accept'] = self.webp_header
         kwargs.setdefault('proxies', self.proxies)
         self.response = self._requests_helper(
             method=method, url=url, headers=headers, cookies=cookies,
